HookReturnValue

Enum HookReturnValue 

pub enum HookReturnValue {
    CallNextHook,
    BlockMessage,
    PassToWindowProcOnly,
    ExplicitValue(LRESULT),
}
Available on crate feature hooking only.
A value indicating what action should be taken after returning from the user callback.

Variants



CallNextHook

Returns the result of calling [CallNextHookEx] with the original raw message, allowing further processing by other hooks.



BlockMessage

Prevents the event from being passed on to the target window procedure or the rest of the hook chain.



PassToWindowProcOnly

Passes the event to the target window procedure but not the rest of the hook chain.



ExplicitValue(LRESULT)