Module hotkey

Module hotkey 

Available on crate feature input only.
Global hotkeys.

Structs

GlobalHotkeySet
Registers global hotkeys.
KeyCombination
A combination of zero or more modifiers and exactly one normal key.
ModifierCombination
A combination of modifier keys.

Enums

Modifier
Modifier key than cannot be used by itself for hotkeys.

Type Aliases

HotkeyId