ExecutableModule

Struct ExecutableModule 

pub struct ExecutableModule { /* private fields */ }
A handle to a module (EXE or DLL).

Implementations

Source

impl ExecutableModule

pub fn from_current_process_exe() -> Result<Self>

Returns the module handle of the currently executed code.

pub fn from_loaded<A: AsRef<Path>>(name: A) -> Result<Self>

Returns the module handle of an already loaded executable with the given name in the current process.

pub fn load_module_as_data_file<P: AsRef<Path>>(file_name: P) -> Result<Self>

Loads a DLL or EXE module as a data file usable for extracting resources.

pub fn load_module<P: AsRef<Path>>(file_name: P) -> Result<Self>

Loads a DLL or EXE module.

pub fn get_symbol_ptr_by_ordinal(&self, ordinal: u16) -> Result<*const c_void>

pub fn get_symbol_ptr_by_name<S: AsRef<str>>( &self, name: S, ) -> Result<*const c_void>