#[repr(i32)]pub enum ProgressState {
NoProgress = 0,
Indeterminate = 1,
Normal = 2,
Error = 4,
Paused = 8,
}ui only.Expand description
Taskbar progress state animation type.
Variants
NoProgress = 0
Stops displaying progress and returns the button to its normal state.
Indeterminate = 1
Shows a “working” animation without indicating a completion percentage.
Normal = 2
Shows a progress indicator displaying the amount of work being completed.
Error = 4
The progress indicator turns red to show that an error has occurred. This is a determinate state. If the progress indicator is in the indeterminate state, it switches to a red determinate display of a generic percentage not indicative of actual progress.
Paused = 8
The progress indicator turns yellow to show that progress is currently stopped. This is a determinate state. If the progress indicator is in the indeterminate state, it switches to a yellow determinate display of a generic percentage not indicative of actual progress.