pub struct NotificationIconOptions {
pub icon_id: NotificationIconId,
pub icon: Rc<Icon>,
pub tooltip_text: Option<String>,
pub visible: bool,
}Available on crate feature
ui only.Expand description
Options for a new notification icon used by Window::add_notification_icon.
Fields
icon_id: NotificationIconIdicon: Rc<Icon>tooltip_text: Option<String>visible: boolTrait Implementations
Sourceimpl Debug for NotificationIconOptions
impl Debug for NotificationIconOptions
Sourceimpl Default for NotificationIconOptions
impl Default for NotificationIconOptions
Sourcefn default() -> NotificationIconOptions
fn default() -> NotificationIconOptions
Returns the “default value” for a type. Read more
impl Eq for NotificationIconOptions
Sourceimpl PartialEq for NotificationIconOptions
impl PartialEq for NotificationIconOptions
Sourcefn eq(&self, other: &NotificationIconOptions) -> bool
fn eq(&self, other: &NotificationIconOptions) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for NotificationIconOptions